#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
[mysqld]
log_warnings = 2
==>
{'mysqld':{'log_warnings':{'key': 'log_warnings','value': 2}}}
"""

import sys
import os
import traceback
import platform

PY3 = False if sys.version_info < (3,) else True
IS_WINDOWS = True if platform.system().lower() == 'windows' else False


class MySQLParse():
    def __init__(self):
        self._cnf_dict = {}

    def read_cnf(self, cnf_path):
        if cnf_path is None:
            return False, "File path is empty."

        if IS_WINDOWS:
            cnf_path = cnf_path.replace('\\', r'/').strip('"')

        cnf_path = os.path.realpath(cnf_path)
        if os.path.exists(cnf_path) is False:
            return False, "File does not exist."

        try:
            cur_section = None
            cnf_reader = open(cnf_path, 'r', encoding='utf-8') if PY3 else open(cnf_path)
            lines = cnf_reader.readlines()
            for line in lines:
                line = line.strip()
                if len(line) <= 0 or '#' == line[0] or ';' == line[0]:
                    continue
                if '[' == line[0] and ']' == line[-1]:
                    cur_section = line[len('['):len(line) - 1]
                    if cur_section not in self._cnf_dict:
                        self._cnf_dict[cur_section] = {}
                elif '=' in line:
                    if cur_section is None:
                        continue
                    index = line.find('=')
                    key = line[0:index].strip().replace('"', '').replace("'", '')
                    value = line[index + 1:].strip()
                    self._set_value(cur_section, key, value)
                else:
                    if cur_section is None:
                        continue
                    key = line
                    self._set_value(cur_section, key, '')
            return True, "Parse the file successfully."

        except:
            return False, "Failed to process include configration file:%s" % traceback.format_exc()

    def _set_value(self, group, key, value):
        key_tmp = key.replace('-', '_')
        self._cnf_dict[group][key_tmp] = {'key': key, 'value': value}

    def get_option(self, group, option):

        if len(group) == 0 or len(option) == 0:
            return None

        option = option.replace('-', '_')

        if group in self._cnf_dict:
            sessions = self._cnf_dict[group]
            if option in sessions:
                return sessions[option]
            else:
                return None
        else:
            return None

    def has_option(self, group, option):
        if len(group) == 0 or len(option) == 0:
            return False

        if group in self._cnf_dict:
            sessions = self._cnf_dict[group]
            if option in sessions:
                return True
        return False

    def pprint_option(self, option, value=None):
        if option == None:
            return ''

        if value != None:
            return '%s = %s' % (option['key'], value)
        else:
            return '%s = %s' % (option['key'], option['value'])

    def pprint(self):
        msg = []
        for key in self._cnf_dict.keys():
            msg.append('[%s]' % key)
            for key1 in self._cnf_dict[key]:
                value = self._cnf_dict[key][key1]['value']
                key2 = self._cnf_dict[key][key1]['key']
                msg.append('%s = %s' % (key2, value))
        return '\n'.join(msg)
